==> apache-rat-0.16.1-src.tar.bz2: apache-rat-0.16.1/apache-rat-core/src/main/java/org/apache/rat/document/RatDocumentAnalysisException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 */ 
package org.apache.rat.document;

public class RatDocumentAnalysisException extends Exception {

    private static final long serialVersionUID = 2339068944003517510L;

    public RatDocumentAnalysisException() {
    }

    public RatDocumentAnalysisException(String msg) {
        super(msg);
    }

    public RatDocumentAnalysisException(Throwable cause) {
        super(cause);
    }

    public RatDocumentAnalysisException(String msg, Throwable cause) {
        super(msg, cause);
    }

}

==> apache-rat-0.17-src.tar.bz2: apache-rat-0.17/apache-rat-core/src/main/java/org/apache/rat/document/RatDocumentAnalysisException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 */
package org.apache.rat.document;

public class RatDocumentAnalysisException extends Exception {

    private static final long serialVersionUID = 2339068944003517510L;

    public RatDocumentAnalysisException(final String msg) {
        super(msg);
    }

    public RatDocumentAnalysisException(final Throwable cause) {
        super(cause);
    }

    public RatDocumentAnalysisException(final String msg, final Throwable cause) {
        super(msg, cause);
    }

}
